#ifndef __ARC_SEC_DENYPDP_H__
#define __ARC_SEC_DENYPDP_H__

#include <stdlib.h>

#include <arc/ArcConfig.h>
#include <arc/security/PDP.h>

namespace ArcSec {

/// This PDP always returns false (deny)
class DenyPDP : public PDP {
 public:
  static Arc::Plugin* get_deny_pdp(Arc::PluginArgument* arg);
  DenyPDP(Arc::Config* cfg,Arc::PluginArgument* parg);
  virtual ~DenyPDP() {};
  virtual bool isPermitted(Arc::Message *msg) const;
};

} // namespace ArcSec

#endif /* __ARC_SEC_DENYPDP_H__ */
